@@ -291,8 +291,11 @@ void InitCompletion::run()
 
 QString InitCompletion::className(const QString &text)
 {
-    Scope sc;
-    Expression exp = getExpression(text, sc);
+    if ( !connectQDevelopDB( getQDevelopPath() + "qdevelop.db" ) )
+    {
+        return QString();
+    }
+    Expression exp = parseLine( text );
     if (exp.access == ParseError)
         return QString();
     return exp.className;
@@ -550,7 +553,6 @@ void InitCompletion::createTables()
     query.exec(queryString);
 }
 //
-
 QStringList InitCompletion::filesList(QString directory, QStringList files)
 {
     QDir dir(directory);
@@ -573,10 +575,13 @@ QStringList InitCompletion::filesList(QString directory, QStringList files)
 void InitCompletion::populateQtDatabase()
 {
    QString command = ctagsCmdPath + " -L "+QDir::tempPath()+"/qdevelopfilenames -f \"" + QDir::tempPath()+"/qttags" +
-                      "\" --language-force=c++ --fields=afiKmsSzn --c++-kinds=cdefgmnpstuvx \""
-                      + m_qtInclude + '\"';
+                      "\" --language-force=c++ --fields=afiKmsSzn --c++-kinds=cdefgmnpstuvx";
+
     QStringList files;
-    files = filesList(m_qtInclude, files);
+    foreach(QString incDir, m_qtInclude)
+    {
+    	files += filesList(incDir, files);
+   	}
      QFile f(QDir::tempPath()+"/qdevelopfilenames");
      if (!f.open(QIODevice::WriteOnly | QIODevice::Text))
          return;
@@ -938,6 +943,16 @@ QString InitCompletion::classForFunction(QString classname, QString function)
 	list = inheritanceList(classname, list);
     createTables();
     QSqlQuery query(QSqlDatabase::database(getQDevelopPath() + "qdevelop.db" ));
+    QStringList listcopy = list;
+    listcopy.removeAll(classname);
+    if (!listcopy.size())
+    {
+    	QString sql = "select count(*) from tags where class ='" + classname +"'";
+		if (!query.exec(sql) || !query.first() || query.value(0).toInt() == 0)
+		{
+			return QString();
+		}
+   	}
 	foreach(QString name, list)
 	{
 	    QString queryString = QString()
@@ -950,5 +965,5 @@ QString InitCompletion::classForFunction(QString classname, QString function)
 	    	return query.value(0).toString().replace("$", "'");
 	    }
 	}
-	return QString();
+	return classname;
 }
