@@ -1,6 +1,6 @@
 /*
 * This file is part of QDevelop, an open-source cross-platform IDE
-* Copyright (C) 2006  Jean-Luc Biord
+* Copyright (C) 2006 - 2010 Jean-Luc Biord
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact e-mail: Trent Zhou <trent.zhou@gmail.com>
-* Program URL   : http://qdevelop.org
+* Program URL   : http://biord-software.org/qdevelop/
 *
 */
 #include <QtCore/QString>
@@ -164,7 +164,13 @@ void CppHighlighter::setupRegexTable()
              << "volatile" << "wchar_t" << "while"
              // BK - Added Qt keywords
              << "slots" << "signals" << "SIGNAL" << "SLOT" << "connect" << "disconnect"
-             << "emit" << "qobject_cast" << "forever";
+             << "emit" << "qobject_cast" << "forever" << "foreach"
+             // Divius: Qt types from QtGlobal
+             << "qint8" << "qint16" << "qint32" << "qint64"
+             << "qlonglong" << "qulonglong" << "qreal"
+             << "quint8" << "quint16" << "quint32" << "quint64"
+             << "qptrdiff" << "quintptr"
+             << "uchar" << "uint" << "ulong" << "ushort";
 
    	//functions and methods
 	item.regex = QRegExp("\\b[a-zA-Z_][a-zA-Z0-9_]+\\s*(?=\\()");
@@ -180,7 +186,6 @@ void CppHighlighter::setupRegexTable()
     
     // user keywords
     QStringList userKeywords;
-    userKeywords << "foreach";
     
     m_userKeywords = QSet<QString>::fromList(userKeywords);    
 }
