@@ -1,6 +1,6 @@
 /*
 * This file is part of QDevelop, an open-source cross-platform IDE
-* Copyright (C) 2006  Jean-Luc Biord
+* Copyright (C) 2006 - 2010 Jean-Luc Biord
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -16,8 +16,8 @@
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
-* Contact e-mail: Jean-Luc Biord <jl.biord@free.fr>
-* Program URL   : http://qdevelop.org
+* Contact e-mail: Jean-Luc Biord <jlbiord@gmail.com>
+* Program URL   : http://biord-software.org/qdevelop/
 *
 */
 #define QD qDebug() << __FILE__ << __LINE__ << ":"
@@ -246,7 +246,35 @@ void Editor::slotTimerUpdateClasses()
 void Editor::slotTimerCheckIfModifiedOutside()
 {
     QFile file(m_filename);
-    if ( m_lastModified != QFileInfo( file ).lastModified() )
+    if ( !file.exists() )
+    {
+    	m_timerCheckLastModified.stop();
+    	int rep = QMessageBox::question(this, "QDevelop",
+                                        tr("The file \"%1\"\ndisappeared from fisk.\n\n").arg(m_filename)+
+                                        tr("What do you want to do?"),
+                                        tr("Recreate"), tr("Close") );
+        if ( rep == 0 ) // Recreate
+        {
+            m_textEdit->document()->setModified( true );
+            save();
+            m_timerCheckLastModified.start( 5000 );
+        }
+        else if ( rep == 1 ) // Closing
+        {
+            QList<Editor *> editors = m_mainimpl->allEditors();
+            for (int i = 0; i < editors.count(); i++)
+            {
+            	qDebug() << editors[i]->filename() << filename(); 
+            	if (editors[i]->filename() == filename())
+            	{
+            		// TODO: Not very good idea to delete object during it's event handler!
+            		m_mainimpl->closeTab(i);
+            		return;
+           		}
+           	}
+        }
+   	}
+   	else if ( m_lastModified != QFileInfo( file ).lastModified() )
     {
         m_timerCheckLastModified.stop();
         int rep = QMessageBox::question(this, "QDevelop",
@@ -678,7 +706,8 @@ void Editor::toggleBookmark(int line)
     m_mainimpl->toggleBookmark(this, s, activate, cursor.block());
     m_textEdit->setTextCursor( save );
     setVerticalScrollBar( scroll );
-    m_textEdit->lineNumbers()->update();
+    if( m_textEdit->lineNumbers() )
+	    m_textEdit->lineNumbers()->update();
 }
 //
 QList<int> Editor::bookmarksList()
@@ -735,7 +764,8 @@ void Editor::toggleBreakpoint(int line, QString breakpointCondition, bool isTrue
     m_textEdit->setTextCursor( save );
     setVerticalScrollBar( scroll );
     emit breakpoint(shortFilename(), line, blockUserData);
-    m_textEdit->lineNumbers()->update();
+    if( m_textEdit->lineNumbers() )
+	    m_textEdit->lineNumbers()->update();
 }
 //
 void Editor::emitListBreakpoints()
@@ -943,7 +973,8 @@ void Editor::slotMessagesBuild(QString list, QString directory)
 		    }
         }
     }
-    m_textEdit->lineNumbers()->update();
+    if( m_textEdit->lineNumbers() )
+	    m_textEdit->lineNumbers()->update();
 	int state = 0;
     for ( QTextBlock block = m_textEdit->document()->begin(); block.isValid(); block = block.next() )
     {
@@ -980,7 +1011,8 @@ void Editor::clearErrorsAndWarnings()
 		    block.setUserData( blockUserData );
        	}
     }
-    m_textEdit->lineNumbers()->update();
+    if( m_textEdit->lineNumbers() )
+    	m_textEdit->lineNumbers()->update();
 }
 
 
