@@ -1,6 +1,6 @@
 /*
 * This file is part of QDevelop, an open-source cross-platform IDE
-* Copyright (C) 2006  Jean-Luc Biord
+* Copyright (C) 2006 - 2010 Jean-Luc Biord
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -16,8 +16,8 @@
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
-* Contact e-mail: Jean-Luc Biord <jl.biord@free.fr>
-* Program URL   : http://qdevelop.org
+* Contact e-mail: Jean-Luc Biord <jlbiord@gmail.com>
+* Program URL   : http://biord-software.org/qdevelop/
 *
 */
 
@@ -32,6 +32,7 @@
 #include <QProgressBar>
 #include <QDebug>
 #include <QLibraryInfo>
+#include <QFile>
 #include "mainimpl.h"
 //
 QSplashScreen *splash = 0;
@@ -75,11 +76,32 @@ int main(int argc, char *argv[])
 	//
 	splash->showMessage(QObject::tr("Loading:")+" "+QObject::tr("Interface translation"), Qt::AlignRight | Qt::AlignTop,  Qt::white);
 	qApp->processEvents();
+	#ifdef Q_OS_WIN32
+	QString defaultTranslationsPath = "/translations";
+	#else
+	QString defaultTranslationsPath = "/../lib/qdevelop/translations";
+	#endif
+	QDir translationsDir(QCoreApplication::applicationDirPath() + defaultTranslationsPath);
 	// load & install QDevelop translation
-	translatorQDevelop.load( ":/translations/translations/QDevelop_"+language+".qm" );
-	app.installTranslator( &translatorQDevelop );
+	translatorQDevelop.load(translationsDir.absoluteFilePath("QDevelop_"+language+".qm"));
+	if (translatorQDevelop.isEmpty())
+	{
+		// Cmake workaround
+		// (checking file existance is necessary as it will try loading other files, including "qdevelop" which might actually exist since
+		//  it is the name of the Linux binary)
+		if (QFile::exists(QCoreApplication::applicationDirPath() + "/QDevelop_"+language+".qm"))
+			translatorQDevelop.load(QCoreApplication::applicationDirPath() + "/QDevelop_"+language+".qm");
+		if (translatorQDevelop.isEmpty())
+		{
+			// Qmake workaround
+			translatorQDevelop.load(QCoreApplication::applicationDirPath() 
+				+ "/../resources/translations/QDevelop_"+language+".qm");
+		}
+	}
+	if (!translatorQDevelop.isEmpty())
+		app.installTranslator( &translatorQDevelop );
 	// search, load & install Qt translation
-	translatorQt.load( ":/translations/translations/Qt_"+language+".qm" );
+	translatorQt.load(translationsDir.absoluteFilePath("qt_"+language+".qm"));
 	if (translatorQt.isEmpty())
 		translatorQt.load( QLibraryInfo::location( QLibraryInfo::TranslationsPath) + "/qt_"+QLocale::system().name()+".qm" );
 	if (!translatorQt.isEmpty())
