@@ -1,6 +1,6 @@
 /*
 * This file is part of QDevelop, an open-source cross-platform IDE
-* Copyright (C) 2006  Jean-Luc Biord
+* Copyright (C) 2006 - 2010 Jean-Luc Biord
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -16,8 +16,8 @@
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
-* Contact e-mail: Jean-Luc Biord <jl.biord@free.fr>
-* Program URL   : http://qdevelop.org
+* Contact e-mail: Jean-Luc Biord <jlbiord@gmail.com>
+* Program URL   : http://biord-software.org/qdevelop/
 *
 */
 #define QD qDebug() << __FILE__ << __LINE__ << ":"
@@ -73,7 +73,7 @@
 //
 
 #define PROJECT_NAME "QDevelop"
-#define VERSION "0.27"
+#define VERSION "0.28-2"
 
 MainImpl::MainImpl(QWidget * parent)
         : QMainWindow(parent)
@@ -431,6 +431,7 @@ void MainImpl::createConnections()
     m_buildingGroup->addAction( actionDebug_mode );
     m_buildingGroup->addAction( actionRelease_mode );
     m_buildingGroup->addAction( action_Forget_last_used_mode );
+    m_buildingGroup->setEnabled( false );
 }
 //
 void MainImpl::slotShortcuts()
@@ -828,6 +829,15 @@ void MainImpl::saveINI()
         settings.endGroup();
     }
     //
+    // HACK to prevent the compiler toolbar from being moved to the right more and more: Hide otherFilesAction button before saving state
+    if (actionOtherFile->isVisible()) {
+        separatorOtherFile->setVisible(false);
+        actionOtherFile->setVisible(false);
+        // yes, we have to call it twice to really update the other toolbars' positions
+        QApplication::processEvents(QEventLoop::ExcludeUserInputEvents);
+        QApplication::processEvents(QEventLoop::ExcludeUserInputEvents);
+    }
+    //
     settings.beginGroup("mainwindowstate");
     if (!isMinimized() && !isMaximized() && !isFullScreen())
     {
@@ -845,6 +855,10 @@ void MainImpl::saveINI()
 	foreach( QWidget *w, dockWidgets )
 		settings.setValue( w->objectName(), toolbarStatus[w] );;
 	settings.endGroup();
+    //
+    // HACK to prevent the compiler toolbar from being moved to the right more and more: Hide otherFilesAction button before saving state
+    // and restore it when we are done
+    slotUpdateOtherFileActions();
 }
 //
 void MainImpl::slotNewProject()
@@ -1133,6 +1147,7 @@ bool MainImpl::openProject(QString s)
     setWindowTitle( s );
     setCurrentProject( s );
     m_projectGroup->setEnabled( true );
+    m_buildingGroup->setEnabled( true );
     slotClickTreeFiles( treeFiles->topLevelItem ( 0 ), 0);
     return true;
 }
@@ -1165,6 +1180,7 @@ bool MainImpl::slotCloseProject(bool /*hide*/)
     m_projectManager = 0;
     setWindowTitle( "QDevelop" );
     m_projectGroup->setEnabled( false );
+    m_buildingGroup->setEnabled( false );
     delete m_findInFiles;
     m_findInFiles = 0;
     return true;
@@ -1333,10 +1349,10 @@ Editor * MainImpl::openFile(QStringList locationsList, int numLine, bool silentM
         	#ifdef Q_OS_MACX
         	if (!QProcess::startDetached (m_linguistName + "/Contents/MacOS/Linguist", QStringList(s)))
         	{
-        		// TODO: Error handling here
+        		QMessageBox::critical(this, "QDevelop", tr("Cannot launch Linguist"));
        		}
         	#else
-        	// TODO: Error handling here
+        	QMessageBox::critical(this, "QDevelop", tr("Cannot launch Linguist"));
         	#endif
        	}
         QApplication::restoreOverrideCursor();
@@ -2437,6 +2453,20 @@ void MainImpl::loadPlugins()
         QObject *plugin = loader.instance();
         if (plugin)
         {
+        	SimplePluginInterface *iSimple = qobject_cast<SimplePluginInterface *>(plugin);
+        	if (iSimple)
+        	{
+                QAction *action = new QAction(iSimple->menuName(), plugin);
+                connect(action, SIGNAL(triggered()), this, SLOT(slotSimplePlugin()));
+                menuPlugins->addAction(action);
+                if ( iSimple->hasConfigDialog() )
+                {
+                    QAction *action = new QAction(iSimple->menuName(), plugin);
+                    connect(action, SIGNAL(triggered()), this, SLOT(slotConfigPlugin()));
+                    menuPluginsSettings->addAction(action);
+                }
+       		}
+       		
             TextEditInterface *iTextEdit = qobject_cast<TextEditInterface *>(plugin);
             if (iTextEdit)
             {
@@ -2459,6 +2489,13 @@ void MainImpl::loadPlugins()
     }
 }
 //
+void MainImpl::slotSimplePlugin()
+{
+	QAction *action = qobject_cast<QAction *>(sender());
+	SimplePluginInterface * iSimple = qobject_cast<SimplePluginInterface *>(action->parent());
+	iSimple->start(this);
+}
+//
 void MainImpl::slotTextEditPlugin()
 {
     Editor *editor = currentEditor();
@@ -2475,6 +2512,9 @@ void MainImpl::slotConfigPlugin()
     TextEditInterface *iTextEdit = qobject_cast<TextEditInterface *>(action->parent());
     if ( iTextEdit )
         iTextEdit->config();
+    SimplePluginInterface * iSimple = qobject_cast<SimplePluginInterface *>(action->parent());
+    if ( iSimple )
+        iSimple->config();
 }
 //
 void MainImpl::resetProjectsDirectoriesList()
