@@ -1,6 +1,6 @@
 /*
 * This file is part of QDevelop, an open-source cross-platform IDE
-* Copyright (C) 2006  Jean-Luc Biord
+* Copyright (C) 2006 - 2010 Jean-Luc Biord
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -16,8 +16,8 @@
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
-* Contact e-mail: Jean-Luc Biord <jl.biord@free.fr>
-* Program URL   : http://qdevelop.org
+* Contact e-mail: Jean-Luc Biord <jlbiord@gmail.com>
+* Program URL   : http://biord-software.org/qdevelop/
 *
 */
 #include "mainimpl.h"
@@ -2071,7 +2071,6 @@ QString ProjectManager::executableName(QString preferedVersion)
     }
     if ( m_executablesList.count() == 1 )
     {
-QD;
         QString choice = m_executablesList.first();
         m_executablesList.clear();
         m_projectDirectoryOfExecutable = m_projectDirectoryOfExecutableList.first();
