@@ -1,6 +1,6 @@
 /*
 * This file is part of QDevelop, an open-source cross-platform IDE
-* Copyright (C) 2006  Jean-Luc Biord
+* Copyright (C) 2006 - 2010 Jean-Luc Biord
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -16,8 +16,8 @@
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
-* Contact e-mail: Jean-Luc Biord <jl.biord@free.fr>
-* Program URL   : http://qdevelop.org
+* Contact e-mail: Jean-Luc Biord <jlbiord@gmail.com>
+* Program URL   : http://biord-software.org/qdevelop/
 *
 */
 //
@@ -1683,14 +1683,16 @@ int TextEdit::lineNumber(QPoint point)
 void TextEdit::slotToggleBookmark()
 {
     m_editor->toggleBookmark( m_lineNumber );
-    m_lineNumbers->update();
+    if( m_lineNumbers )
+	    m_lineNumbers->update();
 }
 //
 //
 void TextEdit::slotToggleBreakpoint()
 {
     m_editor->toggleBreakpoint( m_lineNumber, QString(), true );
-    m_lineNumbers->update();
+    if( m_lineNumbers )
+    	m_lineNumbers->update();
 }
 void TextEdit::insertText(QString text, int insertAfterLine)
 {
